package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.PortOpening;

/**
 * 端口开放Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface PortOpeningMapper 
{
    /**
     * 查询端口开放
     * 
     * @param id 端口开放主键
     * @return 端口开放
     */
    public PortOpening selectPortOpeningById(Integer id);

    /**
     * 查询端口开放列表
     * 
     * @param portOpening 端口开放
     * @return 端口开放集合
     */
    public List<PortOpening> selectPortOpeningList(PortOpening portOpening);

    /**
     * 新增端口开放
     * 
     * @param portOpening 端口开放
     * @return 结果
     */
    public int insertPortOpening(PortOpening portOpening);

    /**
     * 修改端口开放
     * 
     * @param portOpening 端口开放
     * @return 结果
     */
    public int updatePortOpening(PortOpening portOpening);

    /**
     * 删除端口开放
     * 
     * @param id 端口开放主键
     * @return 结果
     */
    public int deletePortOpeningById(Integer id);

    /**
     * 批量删除端口开放
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePortOpeningByIds(Integer[] ids);
}
